@@ -134,7 +134,7 @@ static struct option original_opts[] = {
 	{ "destination-mac", 1, 0, 3},
 	{ "src-mac", 1, 0, 2},
 	{ "dst-mac", 1, 0, 3},
-	{ "h-length", 1, 0,  7 },
+	{ "h-length", 1, 0,  'l' },
 	{ "p-length", 1, 0,  8 },
 	{ "opcode", 1, 0,  4 },
 	{ "h-type", 1, 0,  5 },
@@ -154,7 +154,7 @@ static struct option original_opts[] = {
 	{ 0 }
 };
 
-int NF_ARP_NUMHOOKS = 3;
+int RUNTIME_NF_ARP_NUMHOOKS = 3;
 
 /*#ifndef __OPTIMIZE__
 struct arpt_entry_target *
@@ -605,7 +605,7 @@ cmd2char(int option)
 }
 
 static void
-add_command(int *cmd, const int newcmd, const int othercmds, int invert)
+add_command(unsigned int *cmd, const int newcmd, const unsigned int othercmds, int invert)
 {
 	if (invert)
 		exit_error(PARAMETER_PROBLEM, "unexpected ! flag");
@@ -1281,8 +1281,8 @@ print_firewall(const struct arpt_entry *fw,
 	printf("%s", fw->arp.invflags & ARPT_INV_SRCDEVADDR
 		? "! " : "");
 	printf("--src-mac ");
-	print_mac_and_mask(fw->arp.src_devaddr.addr,
-		fw->arp.src_devaddr.mask, ETH_ALEN);
+	print_mac_and_mask((unsigned char *)fw->arp.src_devaddr.addr,
+		(unsigned char *)fw->arp.src_devaddr.mask, ETH_ALEN);
 	printf(" ");
 after_devsrc:
 
@@ -1305,8 +1305,8 @@ after_devsrc:
 	printf("%s",fw->arp.invflags & ARPT_INV_TGTDEVADDR
 		? "! " : "");
 	printf("--dst-mac ");
-	print_mac_and_mask(fw->arp.tgt_devaddr.addr,
-		fw->arp.tgt_devaddr.mask, ETH_ALEN);
+	print_mac_and_mask((unsigned char *)fw->arp.tgt_devaddr.addr,
+		(unsigned char *)fw->arp.tgt_devaddr.mask, ETH_ALEN);
 	printf(" ");
 after_devdst:
 
@@ -1785,7 +1785,7 @@ int do_command(int argc, char *argv[], char **table, arptc_handle_t *handle)
 		arptables_insmod("arp_tables", modprobe);
 		*handle = arptc_init(*table);
 		if (!*handle) {
-			NF_ARP_NUMHOOKS = 2;
+			RUNTIME_NF_ARP_NUMHOOKS = 2;
 			*handle = arptc_init(*table);
 			if (!*handle) {
 				exit_error(VERSION_PROBLEM,
@@ -1988,7 +1988,7 @@ int do_command(int argc, char *argv[], char **table, arptc_handle_t *handle)
 				            "destination mac");
 			break;
 
-		case 7:/* hardware length */
+		case 'l':/* hardware length */
 			check_inverse(optarg, &invert, &optind, argc);
 			set_option(&options, OPT_H_LENGTH, &fw.arp.invflags,
 				   invert);
